summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/connection.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:48:06 +0000
commit47c8a359c5276062c4bc17f0e82410f29081b502 (patch)
tree2d54a5f60a5b74067632f9ef6df58c2bc38155e6 /kopete/protocols/oscar/liboscar/connection.h
parent6f82532777a35e0e60bbd2b290b2e93e646f349b (diff)
downloadtdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.tar.gz
tdenetwork-47c8a359c5276062c4bc17f0e82410f29081b502.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1157648 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/protocols/oscar/liboscar/connection.h')
-rw-r--r--kopete/protocols/oscar/liboscar/connection.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kopete/protocols/oscar/liboscar/connection.h b/kopete/protocols/oscar/liboscar/connection.h
index 4170857e..f2c1da75 100644
--- a/kopete/protocols/oscar/liboscar/connection.h
+++ b/kopete/protocols/oscar/liboscar/connection.h
@@ -18,8 +18,8 @@ Kopete (c) 2002-2005 by the Kopete developers <kopete-devel@kde.org>
#ifndef CONNECTION_H
#define CONNECTION_H
-#include <qobject.h>
-#include <qvaluelist.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
#include "oscartypes.h"
#include "rateclass.h"
@@ -55,7 +55,7 @@ public:
void setClient( Client* );
- void connectToServer( const QString& server, bool auth = true );
+ void connectToServer( const TQString& server, bool auth = true );
/**
* Close the connection and reset the connection data
*/
@@ -72,14 +72,14 @@ public:
* Get the list of supported families
* @return The list of families supported on this connection
*/
- QValueList<int> supportedFamilies() const;
+ TQValueList<int> supportedFamilies() const;
/**
* Add the SNAC families in \p familyList to the list of supported families for
* this connection
* \param familyList the list of families to add
*/
- void addToSupportedFamilies( const QValueList<int>& familyList );
+ void addToSupportedFamilies( const TQValueList<int>& familyList );
/**
* Add the SNAC family in \p family to the list of supported families for
@@ -94,7 +94,7 @@ public:
* need to be filtered on
* \param rateClassList the list of rate classes to add
*/
- void addToRateClasses( const QValueList<RateClass*> rateClassList );
+ void addToRateClasses( const TQValueList<RateClass*> rateClassList );
/**
* Add the rate class in \p rc to the list of rate classes packets
@@ -125,7 +125,7 @@ public:
/**
* Get the chat room name for this connection.
* @return the name of the room or QString::null if not connected to a room
*/
/** Get the user settings object */
@@ -138,10 +138,10 @@ public:
Q_UINT32 snacSequence();
/** Get the cookie for this connection */
- QByteArray cookie() const;
+ TQByteArray cookie() const;
- QString userId() const;
- QString password() const;
+ TQString userId() const;
+ TQString password() const;
bool isIcq() const;
SSIManager* ssiManager() const;
const Oscar::ClientVersion* version() const;
@@ -176,7 +176,7 @@ signals:
* \param errCode the error code from the operating system
* \param errString the i18n'ed string that describes the error
*/
- void socketError( int errCode, const QString& errString );
+ void socketError( int errCode, const TQString& errString );
private:
@@ -125,7 +125,7 @@ public:
/**
* Get the chat room name for this connection.
- * @return the name of the room or QString::null if not connected to a room
+ * @return the name of the room or TQString::null if not connected to a room
*/
/** Get the user settings object */